@@ -53,6 +53,10 @@
 #include <plugins/config-windows/config-windows.h>
 #endif
 
+#ifdef HAVE_CONFIG_XDP
+#include <plugins/config-xdp/config-xdp.h>
+#endif
+
 #ifdef HAVE_PACRUNNER_DUKTAPE
 #include <plugins/pacrunner-duktape/pacrunner-duktape.h>
 #endif
@@ -194,6 +198,9 @@ px_manager_constructed (GObject *object)
 #ifdef HAVE_CONFIG_WINDOWS
   px_manager_add_config_plugin (self, PX_CONFIG_TYPE_WINDOWS);
 #endif
+#ifdef HAVE_CONFIG_XDP
+  px_manager_add_config_plugin (self, PX_CONFIG_TYPE_XDP);
+#endif
 
   g_debug ("Active config plugins:");
   for (GList *list = self->config_plugins; list && list->data; list = list->next) {
@@ -518,6 +525,8 @@ px_manager_run_pac (PxPacRunner  *pacrunner,
         if (test_uri)
           px_strv_builder_add_proxy (builder, proxy_string);
       }
+    } else if (g_strv_length (word_split) == 1 && g_ascii_strncasecmp (word_split[0], "direct", 6) == 0) {
+      px_strv_builder_add_proxy (builder, "direct://");
     }
   }
 }
@@ -709,7 +718,7 @@ ignore_domain (GUri *uri,
   if (g_strcmp0 (ignore, "*") == 0)
     return TRUE;
 
-  if (!host)
+  if (!host || !ignore || strlen (ignore) == 0)
     return FALSE;
 
   ignore_split = g_strsplit (ignore, ":", -1);
